%global     debug_package %{nil}
%global     GEODA_HOME BuildTools/ubuntu

%define     clapack_ver 3.2.1


ExclusiveArch:  x86_64
Name:       geoda
Version:    1.20.0.22
Release:    %mkrel 1
Summary:    User-friendly and graphical interface to methods of exploratory spatial data analysis
Group:      Sciences/Astronomy
License:    GPLv3+
URL:        https://geodacenter.github.io/
Source0:    https://github.com/GeoDaCenter/geoda/archive/refs/tags/%{name}-%{version}.tar.gz
Source1:    GeoDamake.mageia.opt
Source2:    https://netlib.org/clapack/clapack.tgz
Source3:    clapack-make.inc.mageia
Source10:   geoda.desktop

Patch1:     geoda-1.20-fix-wxrc-patch.patch
Patch2:     geoda-1.20-wo-proj-in-make.patch

BuildRequires:  autoconf
BuildRequires:  cmake
BuildRequires:  cmake(Boost)
BuildRequires:  devel(libgeos_c(64bit))
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(freexl)
BuildRequires:  pkgconfig(gdal)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(glut)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjpeg1)
BuildRequires:  pkgconfig(opengl)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(mariadb)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  pkgconfig(proj) 
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(spatialite)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
BuildRequires:  pkgconfig(xerces-c)
BuildRequires:  pkgconfig(zlib)

BuildRequires:  doxygen
BuildRequires:  json_spirit-devel-static
BuildRequires:  mingw64-boost-static
BuildRequires:  mingw64-win-iconv-static
BuildRequires:  postgresql13-devel
BuildRequires:  spectra-devel = 0.9.0
BuildRequires:  wxgtk-devel

#For integration
Requires:   xdg-utils
#For the icons
Requires:       hicolor-icon-theme

%description
GeoDa is a free and open source software tool that serves as an introduction
to spatial data science. It is designed to facilitate new insights from data 
analysis by exploring and modeling spatial patterns.

%prep
%setup -qn %{name}-%{version}
%autopatch -p1

%build
# Increase stack size, required for xeigtstz, see
# https://github.com/Reference-LAPACK/lapack/issues/335
# Remove for lapack > 3.9
ulimit -s 16384

cd BuildTools/ubuntu/
export GEODA_HOME=$PWD
export GEOLIBDIR=$GEODA_HOME/libraries
mkdir -p $GEOLIBDIR

export CFLAGS="-m64 -std=c++98"
export CXXFLAGS="-m64 -std=c++98"
export LDFLAGS="-m64"

echo "<< Building: Clapack >>" 
%{__tar} -xf %{SOURCE2}
cp -rf $GEODA_HOME/dep/CLAPACK-%{clapack_ver} .

pushd CLAPACK-%{clapack_ver}

cp %{SOURCE3} make.inc

echo "==make f2clib"
%make_build f2clib
cp F2CLIBS/libf2c.a .

echo "==make blaslib"
%make_build blaslib

echo "==make lapack_install"
%make_build lapacklib

echo "==make tmglib"
%make_build tmglib

mv -f blas_LINUX.a blas.a
mv -f lapack_LINUX.a lapack.a
mv -f tmglib_LINUX.a tmglib.a
popd

echo "<< Building: GeoDa >>" 
cp -f %{SOURCE1} ../../GeoDamake.opt
sed -i 's|./libraries/bin/wx-config|/usr/bin/wx-config|g' GNUmakefile
mkdir ../../o
echo "==make compile-geoda"
%make_build
echo "==make build-geoda"
%make_build app

%install
%{__install} -d -m 0755 %{buildroot}%{_libdir}/%{name}
%{__install} -d -m 0755 %{buildroot}%{_libdir}/%{name}/basemap-cache
%{__install} -d -m 0755 %{buildroot}%{_libdir}/%{name}/gdaldata
%{__install} -d -m 0755 %{buildroot}%{_libdir}/%{name}/lang
%{__install} -d -m 0755 %{buildroot}%{_libdir}/%{name}/plugins
%{__install} -d -m 0755 %{buildroot}%{_libdir}/%{name}/proj
%{__install} -d -m 0755 %{buildroot}%{_libdir}/%{name}/Resources
%{__install} -d -m 0755 %{buildroot}%{_libdir}/%{name}/web_plugins

cp -r %{GEODA_HOME}/../CommonDistFiles/gdaldata/* %{buildroot}%{_libdir}/%{name}/gdaldata
cp -r %{GEODA_HOME}/build/lang/* %{buildroot}%{_libdir}/%{name}/lang
cp %{GEODA_HOME}/../CommonDistFiles/proj/* %{buildroot}%{_libdir}/%{name}/proj
cp %{GEODA_HOME}/build/Resources/* %{buildroot}%{_libdir}/%{name}/Resources
cp %{GEODA_HOME}/build/web_plugins/* %{buildroot}%{_libdir}/%{name}/web_plugins

%{__install} -m 755 %{GEODA_HOME}/build/GeoDa %{buildroot}%{_libdir}/%{name}/GeoDa

%{__install} -d -m 0755 %{buildroot}%{_bindir}
ln -sf %{_libdir}/%{name}/GeoDa %{buildroot}%{_bindir}/

%{__install} -m 644 %{GEODA_HOME}/build/cache.sqlite %{buildroot}%{_libdir}/%{name}/
%{__install} -m 644 %{GEODA_HOME}/build/geoda_prefs.json %{buildroot}%{_libdir}/%{name}/
%{__install} -m 644 %{GEODA_HOME}/build/geoda_prefs.sqlite %{buildroot}%{_libdir}/%{name}/

#Icons
%{__install} -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/16x16/apps
%{__install} -m 644 %{GEODA_HOME}/../CommonDistFiles/geoda-logos/GeoDa-no-text-16x16.xpm %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.xpm
%{__install} -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/1800x1800/apps
%{__install} -m 0644 %{GEODA_HOME}/../CommonDistFiles/geoda-logos/png-logos/GeoDa-logo-1800.png %{buildroot}%{_iconsdir}/hicolor/1800x1800/apps/%{name}.png ;

# desktop entry
%{__install} -d -m 0755 %{buildroot}%{_datadir}/applications
%{__install} -m 644 %{SOURCE10} %{buildroot}%{_datadir}/applications/


%files
%doc README.md
%license COPYING copyright_txt.txt
%{_bindir}/GeoDa
%{_iconsdir}/hicolor/*/apps/*.png
%{_iconsdir}/hicolor/*/apps/*.xpm
%{_datadir}/applications/*.desktop
%{_libdir}/%{name}{,.*}

%changelog
* Wed Oct 19 2022 squidf <squid-f> 1.20.0.22-0
- Update 1.20.0.22

* Wed Oct 19 2022 squidf <squid-f> 1.20.0.12-0
- First release for MGA8
